M = Manifold(2, 'M')
X = M.chart('x y')
t = manifolds.RealLine().canonical_coordinate()
c = M.curve([sin(t), sin(2*t)/2], (t, 0, 2*pi), name='c')
v = c.tangent_vector_field()
g = c.plot(thickness=2, aspect_ratio=1) + v.plot(chart=X, number_values=17, scale=0.5)
sphinx_plot(g)